#!/usr/bin/python

""" 
A progam synchronizing the version of translated documents with the last ones of the source (english) version 
"""

# Author: Andrei Boyanov <andrei.boyanov@activesolutions.bg>

import os.path
import fileinput
import sys

englishDir = "english"
destDir = "bulgarian"


def addVersionTag(arg, dirname, names):
	"""
	This function inserts a version tag in every file listed in 'names'
	This function have to be invoked from the os.path.walk function. 
	"""

	cvsEntriesFile = open(englishDir + "/" + dirname + "/CVS/Entries")
	

	# Remove the CVS directory from our list 
	try:
		names.remove("CVS")
	except:
		pass

	for filename in names:  
		version = ""
		# Verify if the file is interresting for us
		if filename.endswith(".wml"):
			full_filename = dirname + "/" + filename
			file = open(full_filename, "r");
			tempfile = open(full_filename + ".TEMP", "w")
			# Verify if the version tag is present
			lines = file.xreadlines()
			for line in lines:
				# I suppose the #use tag are at the begining of the file
				if line.startswith("#use"):
					if not line.startswith("#use wml::debian::translation-check"):
						# 'Normal' #use line - just put it in the new file
						tempfile.write(line)
					
				else:
					# We reached the end of '#use' tags.
					# It's time to put the version tag
				
					if (version == ""):
						# Write version tag if we didn't yet
						cvsEntriesFile.seek(0)
						for cvsEntry in cvsEntriesFile.xreadlines():
							if cvsEntry.startswith("/"+ filename +"/"):
								indexVersionStart = len(filename) + 2
								indexVersionEnd = cvsEntry.index("/", indexVersionStart)
								version = cvsEntry[indexVersionStart:indexVersionEnd]
						# in the case of missing original version ...
						if version == "":
							version = "UNKNOWN"
						if version != "UNKNOWN":
							tempfile.write('#use wml::debian::translation-check translation="' + version + '"\n');
						
					tempfile.write(line)		
			file.close()
			tempfile.close()
			os.remove(full_filename)
			os.rename(full_filename+".TEMP", full_filename)
	cvsEntriesFile.close()



def main():
	global englishDir
	if not englishDir.startswith("/"):
		englishDir = os.getcwd() + "/" + englishDir

	# this script must be ran from the base directory - the one containing the 'english' directory
	if not os.access(englishDir, os.F_OK):
		print "This script must be ran from the base directory - the one containing the 'english' directory"
		sys.exit(-1)

	if len(sys.argv) > 1:
		# Every argument is expected to be a filename to process

		for file in sys.argv[1:]:
			files = []
			print file
			file = file[len(destDir):]
			if not destDir.endswith('/'):
				file = file[1:]
			dir = os.path.dirname(file)
			file = os.path.basename(file)
			files.append(file)
			os.chdir(destDir);
			addVersionTag("", dir, files)

	else:
		# "Caled without arguments - process all the tree" 

		# It's quite dangerous - ask first
		print "Without arguments I will proceed all the " + destDir + " tree. Are really sure to want that ? (yes/no) ",
		response = sys.stdin.readline()
		response = response.strip()
		print response
		if response == "yes":
			os.chdir(destDir)
			os.path.walk(".", addVersionTag, "")
		else:
			print "OK. Bye."


if __name__ == "__main__": 
	main()

